/*
 * ImportContacts.java
 *
 * Copyright (C) 2009 Tim Marston <edam@waxworlds.org>
 *
 * This file is part of the Import Contacts program (hereafter referred
 * to as "this program"). For more information, see
 * http://www.waxworlds.org/edam/software/android/import-contacts
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.waxworlds.importcontacts;

import java.util.Stack;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;

public class ImportContacts extends Activity
{
	public static final int STATE_NONE = 0;
	public static final int STATE_INTRO = 1;
	public static final int STATE_CONFIGURE_VCF = 3;
	public static final int STATE_MERGE = 4;
	public static final int STATE_DOIT = 5;

	private Stack< Integer > _stateStack;

	/** Called when the activity is first created. */
	@Override
    public void onCreate( Bundle savedInstanceState )
    {
		super.onCreate(savedInstanceState);

		_stateStack = new Stack< Integer >();

		if( savedInstanceState == null )
		{
			startState( STATE_INTRO );
		}
		else
		{
			int[] stack = savedInstanceState.getIntArray( "_stateStack" );
			for( int n = 0; n < stack.length; n++ )
				_stateStack.push( stack[ n ] );
			int lastState = _stateStack.pop();
			startState( lastState );
		}
    }

	@Override
	protected void onSaveInstanceState(Bundle outState) {
		super.onSaveInstanceState(outState);
		int[] stack = new int[ _stateStack.size() ];
		for( int n = 0; n < _stateStack.size(); n++ )
			stack[ n ] = _stateStack.elementAt( n );
		outState.putIntArray( "_stateStack", stack );
	}

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data)
	{
		super.onActivityResult(requestCode, resultCode, data);

		// quit?
		if( resultCode == RESULT_CANCELED ) {
			finish();
		}
		else {
			int newState = STATE_NONE;
			if( data != null ) {
				Bundle extras = data.getExtras();
				if( extras != null ) {
					Integer tmp = extras.getInt( "nextstate" );
					if( tmp != null ) {
						newState = tmp.intValue();
					}
				}
			}
			startState( newState );

		}
	}

	private void startState( int newState )
	{
		if( newState == STATE_NONE )
		{
			// we're going back, so pop top state off stack
			_stateStack.pop();
			newState = ( (Integer)_stateStack.peek() ).intValue();
		}
		else
		{
			// push new state on state
			_stateStack.push( new Integer( newState ) );
		}

		// figure out the class
		Class cls = null;
		switch( newState ) {
		case STATE_INTRO: cls = Intro.class; break;
		case STATE_CONFIGURE_VCF: cls = ConfigureVCF.class; break;
		case STATE_MERGE: cls = Merge.class; break;
		case STATE_DOIT: cls = Doit.class; break;
		}

		// start activity
		Intent i = new Intent( this, cls );
		if( _stateStack.size() > 1 ) i.putExtra( "backstate", true );
		startActivityForResult( i, 0 );
	}
}